@@ -2,6 +2,7 @@
 """Honeybee Shade."""
 from __future__ import division
 import math
+import re
 
 from ladybug_geometry.geometry3d.pointvector import Point3D
 from ladybug_geometry.geometry3d.face import Face3D
@@ -9,6 +10,7 @@ from ladybug.color import Color
 
 from ._base import _Base
 from .typing import clean_string
+from .search import get_attr_nested
 from .properties import ShadeProperties
 import honeybee.writer.shade as writer
 
@@ -84,9 +86,16 @@ class Shade(_Base):
             assert data['type'] == 'Shade', 'Expected Shade dictionary. ' \
                 'Got {}.'.format(data['type'])
 
+            # remove any invalid holes from the geometry
+            geo_dict = data['geometry']
+            if 'holes' in geo_dict and geo_dict['holes'] is not None:
+                for i, hole_list in enumerate(geo_dict['holes']):
+                    if len(hole_list) < 3:
+                        geo_dict['holes'].pop(i)
+
+            # serialize the dictionary to an object
             is_detached = data['is_detached'] if 'is_detached' in data else False
-            shade = cls(
-                data['identifier'], Face3D.from_dict(data['geometry']), is_detached)
+            shade = cls(data['identifier'], Face3D.from_dict(geo_dict), is_detached)
             if 'display_name' in data and data['display_name'] is not None:
                 shade.display_name = data['display_name']
             if 'user_data' in data and data['user_data'] is not None:
@@ -246,6 +255,11 @@ class Shade(_Base):
         """
         return math.degrees(self._geometry.azimuth)
 
+    @property
+    def gbxml_type(self):
+        """Get text for the type of object this is in gbXML schema."""
+        return 'Shade'
+
     @property
     def type_color(self):
         """Get a Color to be used in visualizations by type."""
@@ -273,6 +287,27 @@ class Shade(_Base):
         self.display_name = '{}_{}'.format(prefix, self.display_name)
         self.properties.add_prefix(prefix)
 
+    def rename_by_attribute(
+        self, format_str='{display_name} - {gbxml_type}'
+    ):
+        """Set the display name of this Shade using a format string with attributes.
+
+        Args:
+            format_str: Text string for the pattern with which the Shade will be
+                renamed. Any property on this class may be used (eg. energyplus_type)
+                and each property should be put in curly brackets. Nested
+                properties can be specified by using "." to denote nesting levels
+                (eg. properties.energy.construction.display_name). Functions that
+                return string outputs can also be passed here as long as these
+                functions defaults specified for all arguments.
+        """
+        matches = re.findall(r'{([^}]*)}', format_str)
+        attributes = [get_attr_nested(self, m, decimal_count=2) for m in matches]
+        for attr_name, attr_val in zip(matches, attributes):
+            format_str = format_str.replace('{{{}}}'.format(attr_name), attr_val)
+        self.display_name = format_str
+        return format_str
+
     def move(self, moving_vec):
         """Move this Shade along a vector.
 
